@@ -1,5 +1,6 @@
 #ifndef DATA_H
 #define DATA_H
+/* 使用するデータ型を定義する */
 
 #include <stdio.h>
 #include "list.h"
@@ -18,27 +19,47 @@ typedef enum _bool {
     true
 } bool;
 
-typedef struct _project {
+typedef struct {
+    int id;
+    char name[DEFAULT_LENGTH];
+    int sort;
+    int deleted;
+} ProjectInfo;
+ProjectInfo* project_info_new();
+void project_info_free(ProjectInfo*);
+
+typedef struct {
   char name[DEFAULT_LENGTH];
+  char home_description[DEFAULT_LENGTH];
   char home_url[DEFAULT_LENGTH];
 } Project;
 Project* project_new();
 void project_free(Project*);
 
-typedef struct _element {
+typedef struct {
   int element_type_id;
   char* str_val;
   int is_file;
 } Element;
 
-typedef struct _message {
+typedef struct {
+    char name[DEFAULT_LENGTH];
+    char file_name[DEFAULT_LENGTH];
+    int size;
+    char mime_type[DEFAULT_LENGTH];
+    char* content;
+} SettingFile;
+SettingFile* setting_file_new();
+void setting_file_free(SettingFile*);
+
+typedef struct {
   int id;
   List* elements;
 } Message;
 Message* message_new();
 void message_free(Message*);
 
-typedef struct _list_item {
+typedef struct {
   int id;
   int element_type_id;
   char name[256];
@@ -48,7 +69,7 @@ typedef struct _list_item {
 ListItem* list_item_new();
 void list_item_free(ListItem*);
 
-typedef struct _element_type {
+typedef struct {
   int id;
   int type;
   int ticket_property;
@@ -62,13 +83,13 @@ typedef struct _element_type {
   int sort;
 } ElementType;
 
-typedef struct _element_file {
+typedef struct {
     int id;
     int element_type_id;
     char name[DEFAULT_LENGTH];
     int size;
     char mime_type[DEFAULT_LENGTH];
-    char* blob;
+    char* content;
 } ElementFile;
 ElementFile* element_file_new();
 void element_file_free(ElementFile*);
@@ -94,10 +115,11 @@ enum ELEM_ID {
 };
 #define BASIC_ELEMENT_MAX 3
 
-typedef struct _condition {
+typedef struct {
   int element_type_id;
   int condition_type;
   char value[DEFAULT_LENGTH];
+  char cookie_value[DEFAULT_LENGTH];
 } Condition;
 enum CONDITION_TYPE {
     CONDITION_TYPE_NORMAL,
@@ -106,17 +128,19 @@ enum CONDITION_TYPE {
 };
 Condition* condition_new();
 void condition_free(Condition*);
-void set_condition_values(Condition*, int, int, char*);
+void set_condition_values(Condition*, int, int, char*, char*, bool);
 char* get_condition_value(List*, int, int);
 int valid_condition_size(List*);
+bool valid_condition(Condition*);
+char* get_condition_valid_value(Condition*);
 
-typedef struct _state {
+typedef struct {
   int id;
   char name[DEFAULT_LENGTH];
   int count;
 } State;
 
-typedef struct _search_result {
+typedef struct {
   int hit_count;
   int page;
   List* messages;
@@ -125,7 +149,7 @@ typedef struct _search_result {
 SearchResult* search_result_new();
 void search_result_free(SearchResult*);
 
-typedef struct _wiki {
+typedef struct {
   int id;
   char name[DEFAULT_LENGTH];
   char* content;
