@@ -7,6 +7,7 @@
 #include "db_top.h"
 #include "dbutil.h"
 #include "list.h"
+#include "alloc.h"
 #include "util.h"
 #include "wiki.h"
 #include "hook.h"
@@ -102,12 +103,12 @@ void output_header(Project* project, char* title, char* script_name, const NaviT
     cgiHeaderContentType("text/html; charset=utf-8;");
     /* Top of the page */
     o(      "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n"
-            "<html xml:lang=\"ja\" lang=\"ja\" xmlns=\"http://www.w3.org/1999/xhtml\">\n"
+            "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n"
             "<head>\n"
             "\t<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" />\n"
             "\t<meta http-equiv=\"Content-Script-Type\" content=\"text/javascript\" />\n"
             "\t<meta http-equiv=\"Content-Style-type\" content=\"text/css\" />\n");
-    o(        "\t<title>"); h(project->name); o(" - %s</title>\n", title);
+    o(        "\t<title>"); h(project->name); o(" - "); h(title); o("</title>\n");
     o(      "\t<link rel=\"stylesheet\" type=\"text/css\" href=\"%s/../css/style.css\" />\n", cgiScriptName);
     o(      "\t<link rel=\"stylesheet\" type=\"text/css\" href=\"%s/%s/setting_file/user.css\" />\n", cgiScriptName, g_project_name_4_url);
     if (script_name) {
@@ -124,7 +125,6 @@ void output_header(Project* project, char* title, char* script_name, const NaviT
       "<ul>\n");
     o("\t<li><a href='%s/%s/rss' title=\"RSS Feed\"><img src=\"%s/../img/rss.png\" alt=\"rss\" /></a></li>\n", cgiScriptName, g_project_name_4_url, cgiScriptName);
     o("\t<li><a href='%s/top/' title=\"トップページのサブプロジェクト一覧を表示します\">トップページ(サブプロジェクト一覧)</a></li>\n", cgiScriptName);
-    o("\t<li><a href='%s' title=\"ホームへ移動します\">", project->home_url); h(project->home_description); o("</a></li>\n");
     o("</ul>\n"
       "<br clear='all' />\n"
       "</div>\n");
@@ -1223,7 +1223,7 @@ void ticket_action()
     o(" &nbsp;</h2>\n");
     o(      "<div id=\"ticket_newest\">\n"
             "<h3>チケット最新情報</h3>\n"
-            "<div class=\"description\">チケットの最新情報です。最新チケットのチケット属性の付いている属性と全添付ファイルを表示しています。</div>\n"
+            "<div class=\"description\">チケットの最新情報です。最新チケットのチケット属性の付いている項目と全添付ファイルを表示しています。</div>\n"
             "<table summary=\"newest table\">\n"
             "\t<tr>\n"
             "\t\t<th>ID</th>\n"
@@ -2124,12 +2124,12 @@ got_item:
                 foreach (it_item, items_a) {
                     State* s = it_item->element;
                     int count = s == NULL ? 0 : s->count;
-                    o("\t\t[\""); h(s->name); o("\t(%d)\", %d]", count, count);
+                    o("\t\t[\""); o(s->name); o("\t(%d)\", %d]", count, count); /* html5ライブラリ側でエスケープしてるので、s->nameはエクケープしない */
                     if (iterator_next(it_item)) o(",");
                     o("\n");
                 }
                 o(      "\t\t];\n"
-                        "\t\tdocument.write('<canvas height=\"300\" id=\"graph_%d\"></canvas>');\n"
+                        "\t\tdocument.write('<canvas id=\"graph_%d\"></canvas>');\n"
                         "\t\t// -->\n"
                         "\t\t</script>\n", et->id);
                 o("</div>\n");
