@@ -1,12 +1,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <stdlib.h>
 #include <time.h>
 #include <sys/time.h>
 #include <cgic.h>
 #include <iconv.h>
 #include <errno.h>
+#include "alloc.h"
 #include "util.h"
 #include "hook.h"
 
@@ -25,26 +25,7 @@ void redirect_raw(const char*);
 void page_not_found();
 
 Action* actions = NULL;
-int alloc_count = 0;
 
-void* xalloc(size_t size)
-{
-    void* p;
-    p = calloc(1, size);
-    if (!p) {
-        die("memory error.");
-    }
-    alloc_count++;
-/*     d("xalloc: %p\n", p); */
-    return p;
-}
-void xfree(void* p)
-{
-/*     d("xfree: %p\n", p); */
-    alloc_count--;
-    free(p);
-    p = NULL;
-}
 static Action* get_actions()
 {
     return actions;
@@ -73,7 +54,7 @@ void free_action_actions()
         xfree(old);
     }
     xfree(actions);
-    d("alloc_count: %d\n", alloc_count);
+    d("alloc_count: %d\n", get_alloc_count());
 }
 
 /* 復帰できないエラーが発生した場合にエラーページを表示する。 */
@@ -120,7 +101,7 @@ ActionType analysis_action()
         strncpy(g_project_name, path_info + 1, DEFAULT_LENGTH);
     } else {
         redirect_raw("top");
-        die("redirect to top.");
+        return ret; /* ACTION_TYPE_NONE を返却する。 */
     }
     if ((index = strchr(g_project_name, '/'))) {
         *index = '\0';
@@ -221,10 +202,10 @@ int get_ticket_syntax_len(char* data, size_t len, char* project_id, char* ticket
 
         while (index++, 1) { /* each char */
             /* 
-             *              * 一文字つづ進めていく。
-             *                           * 途中でチケットリンクでないと判定された場合は、index を 0 にして、breakする。
-             *                                        * チケットリンクが終了したら、breakする。
-             *                                                     */
+             * 一文字つづ進めていく。
+             * 途中でチケットリンクでないと判定された場合は、index を 0 にして、breakする。
+             * チケットリンクが終了したら、breakする。
+             */
             if (string[index] == '\0') {
                 break;
             } else if (project_mode) {
@@ -391,6 +372,49 @@ static cgiFormResultType cgiHtmlEscapeDataMailaddress(char *data, int len)
     }
     return cgiFormSuccess;
 }
+static cgiFormResultType cgi_html_escape(char *data, int len)
+{
+    while (len--) {
+        if (*data == '<') {
+            TRYPUTC('&');
+            TRYPUTC('l');
+            TRYPUTC('t');
+            TRYPUTC(';');
+        } else if (*data == '&') {
+            TRYPUTC('&');
+            TRYPUTC('a');
+            TRYPUTC('m');
+            TRYPUTC('p');
+            TRYPUTC(';');
+        } else if (*data == '>') {
+            TRYPUTC('&');
+            TRYPUTC('g');
+            TRYPUTC('t');
+            TRYPUTC(';');
+        } else if (*data == '"') {
+            TRYPUTC('&');
+            TRYPUTC('q');
+            TRYPUTC('o');
+            TRYPUTC('u');
+            TRYPUTC('t');
+            TRYPUTC(';');
+        } else if (*data == '\'') {
+            TRYPUTC('&');
+            TRYPUTC('#');
+            TRYPUTC('3');
+            TRYPUTC('9');
+            TRYPUTC(';');
+        } else {
+            TRYPUTC(*data);
+        }
+        data++;
+    }
+    return cgiFormSuccess;
+}
+void cgi_escape(char *s)
+{
+    cgi_html_escape(s, (int) strlen(s));
+}
 
 void hmail(char *s)
 {
